Accelerator, radiation and x-ray optics simulation framework

# Ocelot

Ocelot is an open-source multiphysics simulation toolkit for accelerator physics.  
It is designed to model Free Electron Lasers (FELs), storage rings, and transport lines using a modular and scriptable Python interface.

- **Website**: [https://www.ocelot-collab.com](https://www.ocelot-collab.com)
- **Documentation**: [https://www.ocelot-collab.com/docs/docu/intro](https://www.ocelot-collab.com/docs/docu/intro)
- **Tutorials**: [https://www.ocelot-collab.com/docs/tutorial/intro](https://www.ocelot-collab.com/docs/tutorial/intro)
- **Source code**: [https://github.com/ocelot-collab/ocelot](https://github.com/ocelot-collab/ocelot)
- **Bug reports**: [https://github.com/ocelot-collab/ocelot/issues](https://github.com/ocelot-collab/ocelot/issues)
- **License**: [GPL-3.0 license](https://github.com/ocelot-collab/ocelot/blob/master/LICENSE)

---

## Features

Ocelot provides:

- A modular framework for beam dynamics simulations (tracking, optics, matching)
- Physics processes including:
  - Space charge
  - Coherent synchrotron radiation (CSR)
  - Wakefields
  - and many more
- A framework for FEL-related studies and synchrotron calculation
- Jupyter-based interactive tutorials for education and development


---

## Getting Started

For requirements and installation instructions, see the official guide:  
👉 [**Installation & Setup**](https://www.ocelot-collab.com/docs/docu/intro)

To explore tutorials, visit:  
👉 [**Tutorial Overview**](https://www.ocelot-collab.com/docs/tutorial/intro)  
👉 [**Student-Friendly Introduction**](https://www.ocelot-collab.com/docs/tutorial/tutorial-beam-dynamics/for_students)

---

We welcome feedback, contributions, and new ideas from the accelerator community!

- [How to create a pull request](https://www.ocelot-collab.com/docs/docu/how-to/pull_request)
- [How to add unit tests](https://www.ocelot-collab.com/docs/docu/how-to/unit_test)
- [How to create your own Physics Process class](https://www.ocelot-collab.com/docs/docu/how-to/phys_proc)

**Disclaimer:** The OCELOT code comes with absolutely NO warranty. The authors of the OCELOT do not take any responsibility for any damage to equipments or personnel injury that may result from the use of the code.
